<?php
/**
 * Plugin Name: Ultimate Social Share
 * Plugin URI: http://club.wpeka.com/
 * Description: Make sharing easy - add a floating social media box that scrolls with your content.
 * Version: 1.2
 * Author: WPEka
 * Author URI: http://WpEka.com
 * Text Domain: ultimatesocial
 * @package UltimateSocial
 * @category Core
 * @author WPEka
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

if ( ! class_exists( 'UltimateSocialShare' ) ) :

/**
 * Main ultimateSocialShare Class
 *
 * @class ultimateSocialShare
 * @version	1.0.0
 */
final class UltimateSocialShare {

	/**
	 * @var string
	 */
	public $version = '1.0.0';

	/**
	 * @var ultimateSocialShare The single instance of the class
	 * @since 1.0
	 */
	protected static $_instance = null;

	/**
	 * @var WPEka_Session session
	 */
	public $query = null;

		public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	/**
	 * Cloning is forbidden.
	 *
	 * @since 1.0
	 */
	public function __clone() {
		_doing_it_wrong( __FUNCTION__, __( 'Cheatin&#8217; huh?' ), '1.0' );
	}

	
	/**
	 * ultimateSocialShare Constructor.
	 * @access public
	 * @return ultimateSocialShare
	 */
	public function __construct() {
		
		// Define constants
		$this->define_constants();

		// Include required files
		$this->includes();
              load_plugin_textdomain( 'uss', false, dirname( plugin_basename( __FILE__ ) ) . '/languages' ); 
		
	}
	

	/**
	 * Define WC Constants
	 */
	private function define_constants() {
		define( 'USS_PLUGIN_PATH', WP_PLUGIN_URL.'/'.basename(__DIR__) );
		define( 'USS_PLUGIN_FILE', __FILE__ );
		define( 'USS_VERSION', $this->version );		
	}

	/**
	 * Include required core files used in admin and on the frontend.
	 */
	private function includes() {
		
		if (is_admin()) {
			include_once( 'includes/admin/class-USS-admin.php' );
		}
		else {
			include_once( 'includes/class-USS-public.php' );
		}

	}
	
	/** Deprecated methods *********************************************************/

	/**
	 * @deprecated 1.0.0
	 * @return WPEka_Logger
	 */
	public function logger() {
		_deprecated_function( 'UltimateSocialMedia->logger', '1.0', 'new UltimateSocialMedia_Logger()' );
		return new ultimateSocialShare_Logger();
	}

}

endif;

/**
 * Returns the main instance of WP to prevent the need to use globals.
 *
 * @since  1.0
 * @return WPEkaPlugin
 */
function USM() {
	return UltimateSocialShare::instance();
}

// Global for backwards compatibility.
$GLOBALS['ultimateSocialShare'] = USM();


if((is_admin() && get_transient('UltimateSocialShare_update_check_flag') != 'checked_update')) {
	add_action('admin_init' , 'UltimateSocialShare_process_wpeka_login_request');
	require_once(dirname(__FILE__)."/includes/UltimateSocialShare-class-updater.php");
	$token = get_option('wpeka_member_token');
	$username = get_option('wpeka_member_username');
	if($token != false && $username != false) {
			new UltimateSocialShare_updater($username.' , '.$token, plugin_basename(__FILE__) , 'ultimate_social_share');
			set_transient('UltimateSocialShare_update_check_flag' , 'checked_update' , 60* 60 *24 *7);
	}else {
		add_action('admin_notices', 'UltimateSocialShare_admin_notice');
	}
}
define('USS_PLUGIN_DIR_PATH',plugin_dir_path(__FILE__) );
define('USS_PLUGIN_FILE_PATH',__FILE__);

include_once(USS_PLUGIN_DIR_PATH.'wpeka_plugin_verifier.php');
